==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/UseCaseAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.usecase.BinaryAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.ExtendSet;
import io.ciera.tool.sql.ooaofooa.usecase.GeneralizationSet;
import io.ciera.tool.sql.ooaofooa.usecase.IncludeSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociation;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.BinaryAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.usecase.impl.ExtendSetImpl;
import io.ciera.tool.sql.ooaofooa.usecase.impl.GeneralizationSetImpl;
import io.ciera.tool.sql.ooaofooa.usecase.impl.IncludeSetImpl;

import java.util.Arrays;
import java.util.List;


public class UseCaseAssociationSetImpl extends InstanceSet<UseCaseAssociationSet,UseCaseAssociation> implements UseCaseAssociationSet {

    // attributes
    @Override
    public void setDestination_Part_ID( UniqueId ref_Destination_Part_ID ) throws XtumlException {
        for ( UseCaseAssociation usecaseassociation : this ) usecaseassociation.setDestination_Part_ID( ref_Destination_Part_ID );
    }
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( UseCaseAssociation usecaseassociation : this ) usecaseassociation.setAssoc_ID( ref_Assoc_ID );
    }
    @Override
    public void setSource_Part_ID( UniqueId ref_Source_Part_ID ) throws XtumlException {
        for ( UseCaseAssociation usecaseassociation : this ) usecaseassociation.setSource_Part_ID( ref_Source_Part_ID );
    }


    // selections
    @Override
    public InteractionParticipantSet R1206_starts_at_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) interactionparticipantset.add( usecaseassociation.R1206_starts_at_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public InteractionParticipantSet R1207_ends_at_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) interactionparticipantset.add( usecaseassociation.R1207_ends_at_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public BinaryAssociationSet R1210_is_a_BinaryAssociation() throws XtumlException {
        BinaryAssociationSet binaryassociationset = new BinaryAssociationSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) binaryassociationset.add( usecaseassociation.R1210_is_a_BinaryAssociation() );
        return binaryassociationset;
    }
    @Override
    public ExtendSet R1210_is_a_Extend() throws XtumlException {
        ExtendSet extendset = new ExtendSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) extendset.add( usecaseassociation.R1210_is_a_Extend() );
        return extendset;
    }
    @Override
    public GeneralizationSet R1210_is_a_Generalization() throws XtumlException {
        GeneralizationSet generalizationset = new GeneralizationSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) generalizationset.add( usecaseassociation.R1210_is_a_Generalization() );
        return generalizationset;
    }
    @Override
    public IncludeSet R1210_is_a_Include() throws XtumlException {
        IncludeSet includeset = new IncludeSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) includeset.add( usecaseassociation.R1210_is_a_Include() );
        return includeset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) packageableelementset.add( usecaseassociation.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public UseCaseAssociation nullElement() {
        return UseCaseAssociationImpl.EMPTY_USECASEASSOCIATION;
    }

    @Override
    public UseCaseAssociationSet emptySet() {
      return new UseCaseAssociationSetImpl();
    }

    @Override
    public UseCaseAssociationSet value() {
        return this;
    }

    @Override
    public List<UseCaseAssociation> elements() {
        return Arrays.asList(toArray(new UseCaseAssociation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/UseCaseAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.usecase.BinaryAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.ExtendSet;
import io.ciera.tool.sql.ooaofooa.usecase.GeneralizationSet;
import io.ciera.tool.sql.ooaofooa.usecase.IncludeSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociation;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.BinaryAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.usecase.impl.ExtendSetImpl;
import io.ciera.tool.sql.ooaofooa.usecase.impl.GeneralizationSetImpl;
import io.ciera.tool.sql.ooaofooa.usecase.impl.IncludeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class UseCaseAssociationSetImpl extends InstanceSet<UseCaseAssociationSet,UseCaseAssociation> implements UseCaseAssociationSet {

    public UseCaseAssociationSetImpl() {
    }

    public UseCaseAssociationSetImpl(Comparator<? super UseCaseAssociation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDestination_Part_ID( UniqueId ref_Destination_Part_ID ) throws XtumlException {
        for ( UseCaseAssociation usecaseassociation : this ) usecaseassociation.setDestination_Part_ID( ref_Destination_Part_ID );
    }
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( UseCaseAssociation usecaseassociation : this ) usecaseassociation.setAssoc_ID( ref_Assoc_ID );
    }
    @Override
    public void setSource_Part_ID( UniqueId ref_Source_Part_ID ) throws XtumlException {
        for ( UseCaseAssociation usecaseassociation : this ) usecaseassociation.setSource_Part_ID( ref_Source_Part_ID );
    }


    // selections
    @Override
    public InteractionParticipantSet R1206_starts_at_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) interactionparticipantset.add( usecaseassociation.R1206_starts_at_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public InteractionParticipantSet R1207_ends_at_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) interactionparticipantset.add( usecaseassociation.R1207_ends_at_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public BinaryAssociationSet R1210_is_a_BinaryAssociation() throws XtumlException {
        BinaryAssociationSet binaryassociationset = new BinaryAssociationSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) binaryassociationset.add( usecaseassociation.R1210_is_a_BinaryAssociation() );
        return binaryassociationset;
    }
    @Override
    public ExtendSet R1210_is_a_Extend() throws XtumlException {
        ExtendSet extendset = new ExtendSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) extendset.add( usecaseassociation.R1210_is_a_Extend() );
        return extendset;
    }
    @Override
    public GeneralizationSet R1210_is_a_Generalization() throws XtumlException {
        GeneralizationSet generalizationset = new GeneralizationSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) generalizationset.add( usecaseassociation.R1210_is_a_Generalization() );
        return generalizationset;
    }
    @Override
    public IncludeSet R1210_is_a_Include() throws XtumlException {
        IncludeSet includeset = new IncludeSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) includeset.add( usecaseassociation.R1210_is_a_Include() );
        return includeset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( UseCaseAssociation usecaseassociation : this ) packageableelementset.add( usecaseassociation.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public UseCaseAssociation nullElement() {
        return UseCaseAssociationImpl.EMPTY_USECASEASSOCIATION;
    }

    @Override
    public UseCaseAssociationSet emptySet() {
      return new UseCaseAssociationSetImpl();
    }

    @Override
    public UseCaseAssociationSet emptySet(Comparator<? super UseCaseAssociation> comp) {
      return new UseCaseAssociationSetImpl(comp);
    }

    @Override
    public UseCaseAssociationSet value() {
        return this;
    }

    @Override
    public List<UseCaseAssociation> elements() {
        return Arrays.asList(toArray(new UseCaseAssociation[0]));
    }

}
